@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.125';
+our $VERSION = '0.126';
 
 use feature 'switch';
 
@@ -234,7 +234,10 @@ sub set_package_name {
         $pkgname = Debian::Control::FromCPAN->module_name_to_pkg_name( $self->perlname );
     }
 
-    if ( $self->perlname =~ /^App-/ && !defined $self->cfg->packagename ) {
+    if (   $self->perlname =~ /^App-/
+        && !defined $self->cfg->packagename
+        && !$self->isa("DhMakePerl::Command::refresh") )
+    {
         ( my $suggestion = $pkgname ) =~ s/^libapp-(.+)-perl$/$1/;
         print "******\n";
         print "NOTICE\n";
