@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.125';
+our $VERSION = '0.126';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -561,7 +561,7 @@ sub create_changelog {
     my $closes = $bug ? " (Closes: #$bug)" : '';
     my $changelog_dist = $self->cfg->pkg_perl ? "UNRELEASED" : "unstable";
 
-    $fh->printf( "%s (%s) %s; urgency=low\n",
+    $fh->printf( "%s (%s) %s; urgency=medium\n",
         $self->srcname, $self->pkgversion, $changelog_dist );
     $fh->print("\n  * Initial release.$closes\n\n");
     $fh->printf( " -- %s  %s\n", $self->get_developer,
